@@ -1,29 +1,27 @@
 import io
-import tempfile
+import logging
 import traceback
-import urllib
 from typing import List, Tuple, Dict
-from urllib.parse import urlparse
 
 import pandas as pd
-import requests
-import webdav.client as wc
 import xlrd
 
 import nexinfosys
 from nexinfosys.command_generators import IType
 from nexinfosys.common.helper import any_error_issue, download_file
-from nexinfosys.model_services import get_case_study_registry_objects
+from nexinfosys.model_services import get_case_study_registry_objects, State
 from nexinfosys.model_services.workspace import InteractiveSession, prepare_and_solve_model
 from nexinfosys.models.musiasem_methodology_support import DBSession
 from nexinfosys.initialization import initialize_databases, get_parameters_in_state, get_scenarios_in_state, \
     register_external_datasources, get_graph_from_state, get_dataset_from_state, get_model, get_geolayer, get_ontology, \
     validate_command, command_field_help, comm_help
 from nexinfosys import initialize_configuration
+from nexinfosys.serialization import serialize_state, deserialize_state
 
 
 class NIS:
     def __init__(self):
+        logging.basicConfig(level=logging.DEBUG)
         self._isession = None
         self._rsession = None
         self._dataframe_names = []  # type: List[str]
@@ -46,8 +44,10 @@ class NIS:
 
     # --------------- SESSION ---------------
 
-    def open_session(self, reset_commands=False):
+    def open_session(self, reset_commands=False, state: State=None):
         self._isession = InteractiveSession(DBSession)
+        if state:
+            self._isession.state = state
         self._isession.identify({"user": "test_user", "password": None}, testing=True)
         self._rsession = self._isession.open_reproducible_session(case_study_version_uuid=None,
                                                                   recover_previous_state=False,
@@ -84,7 +84,8 @@ class NIS:
         """
         # Load a XLSX workbook into memory, as dataframes
         bytes_io = download_file(fname, wv_user, wv_password, wv_host_name)
-        xl = pd.ExcelFile(xlrd.open_workbook(file_contents=bytes_io.getvalue()), engine="xlrd")
+        xl = pd.ExcelFile(bytes_io, engine='openpyxl')
+        # xl = pd.ExcelFile(xlrd.open_workbook(file_contents=bytes_io.getvalue()), engine="xlrd")
         cont = 0
         for sheet_name in xl.sheet_names:
             df = xl.parse(sheet_name, header=0)
@@ -162,7 +163,7 @@ class NIS:
 
     # --------------- SUBMISSION ---------------
 
-    def submit(self) -> List:
+    def submit(self, ignore_imports=False) -> List:
         if len(self._dataframes) == 0:
             raise Exception("The list of dataframes is empty. Cannot submit.")
 
@@ -175,12 +176,12 @@ class NIS:
             generator_type = "spreadsheet"
             content_type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
             buffer = self._generate_in_memory_excel()
-            print(len(buffer))
+            logging.debug(len(buffer))
             execute = True
             register = False
 
             try:
-                ret = self._isession.register_andor_execute_command_generator(generator_type, content_type, buffer, register, execute)
+                ret = self._isession.register_andor_execute_command_generator(generator_type, content_type, buffer, register, execute, ignore_imports)
                 if isinstance(ret, tuple):
                     issues = ret[0]
                 else:
@@ -456,6 +457,36 @@ class NIS:
 
 
 if __name__ == '__main__':
+    nis = NIS()
+    nis.open_session(True)
+    nis.reset_commands()
+    # Load file and execute it
+    nis.load_workbook("https://docs.google.com/spreadsheets/d/15NNoP8VjC2jlhktT0A8Y0ljqOoTzgar8l42E5-IRD90/edit#gid=2056162596")
+    issues = nis.submit()
+
+    tmp = nis.query_available_datasets()
+    print("-------------------")
+    print(tmp)
+    d = nis.get_results([(tmp[0]["type"], tmp[0]["name"])])
+    print(d)
+
+    serial_state = serialize_state(nis.get_state())
+    nis.close_session()
+    # -------------------
+    for i in range(10):
+        nis = NIS()
+        nis.open_session(True, deserialize_state(serial_state))
+        nis.load_workbook("https://docs.google.com/spreadsheets/d/1z8QKYkvlUPLAwo6NYM8rRLMj7_QjPRYOgAsTRI2HwWE/edit#gid=1467907392")
+        nis.submit(ignore_imports=True)
+
+        tmp = nis.query_available_datasets()
+        print("-------------------")
+        print(tmp)
+        d = nis.get_results([(tmp[0]["type"], tmp[0]["name"])])
+        print(d)
+
+        nis.close_session()
+
     examples = [
         ("https://docs.google.com/spreadsheets/d/1z8QKYkvlUPLAwo6NYM8rRLMj7_QjPRYOgAsTRI2HwWE/edit#gid=1467907392", False),
         ("https://docs.google.com/spreadsheets/d/12AlJ0tdu2b-cfalNzLqFYfiC-hdDlIv1M1pTE3AfSWY/edit#gid=84311637", False),
